@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////////
-// Copyright (c) 2009-2011 Alan Wright. All rights reserved.
+// Copyright (c) 2009-2014 Alan Wright. All rights reserved.
 // Distributable under the terms of either the Apache License (Version 2.0)
 // or the GNU Lesser General Public License.
 /////////////////////////////////////////////////////////////////////////////
@@ -10,15 +10,12 @@
 
 using namespace Lucene;
 
-BOOST_FIXTURE_TEST_SUITE(CompressionToolsTest, LuceneTestFixture)
+typedef LuceneTestFixture CompressionToolsTest;
 
-BOOST_AUTO_TEST_CASE(testCompressDecompress)
-{
+TEST_F(CompressionToolsTest, testCompressDecompress) {
     ByteArray compress(CompressionTools::compressString(L"test compressed string"));
-    BOOST_CHECK(compress.size() > 0);
-    
-    String decompress(CompressionTools::decompressString(compress));
-    BOOST_CHECK_EQUAL(decompress, L"test compressed string");
-}
+    EXPECT_TRUE(compress.size() > 0);
 
-BOOST_AUTO_TEST_SUITE_END()
+    String decompress(CompressionTools::decompressString(compress));
+    EXPECT_EQ(decompress, L"test compressed string");
+}
